@@ -1,26 +1,32 @@
 from __future__ import annotations
 
-import typing as _t
-from dataclasses import dataclass as _dataclass
+import typing as t
+from dataclasses import dataclass
 
 from .utils import LazyLoader
 from .utils import MODELS_URL
 from .utils import download_model
 
-if _t.TYPE_CHECKING:
+if t.TYPE_CHECKING:
     from . import api
 else:
     api = LazyLoader("api", globals(), "whispercpp.api")
     del LazyLoader
 
 
-@_dataclass
+@dataclass
 class Whisper:
-    def __init__(self, *args: _t.Any, **kwargs: _t.Any):
+    def __init__(self, *args: t.Any, **kwargs: t.Any):
         raise RuntimeError(
             "Using '__init__()' is not allowed. Use 'from_pretrained()' instead."
         )
 
+    if t.TYPE_CHECKING:
+        # The following will be populated by from_pretrained.
+        _ref: api.WhisperPreTrainedModel
+        context: api.Context
+        params: api.Params
+
     @classmethod
     def from_pretrained(cls, model_name: str):
         if model_name not in MODELS_URL:
